@@ -10,6 +10,9 @@ import simplejson
 
 from fixtures import muchdata, reset_textstore, _teststore
 
+
+from tiddlyweb.util import sha
+
 text_put_body=u"""modifier: JohnSmith
 created: 
 modified: 200803030303
@@ -60,7 +63,8 @@ def test_put_tiddler_txt_3():
     response, content = http.request('http://our_test_domain:8001/bags/bag1/tiddlers/TestOne',
             method='PUT', headers={'Content-Type': 'text/plain'}, body=encoded_body)
     assert response['status'] == '204'
-    assert response['etag'] == '"bag1/TestOne/3;text/plain"'
+    etag_hash = sha('GUEST:text/plain').hexdigest()
+    assert response['etag'] == '"bag1/TestOne/3;%s"' % etag_hash
 
 def test_put_tiddler_txt_4():
     http = httplib2.Http()
@@ -68,7 +72,8 @@ def test_put_tiddler_txt_4():
     response, content = http.request('http://our_test_domain:8001/bags/bag1/tiddlers/TestOne',
             method='PUT', headers={'Content-Type': 'text/plain'}, body=encoded_body)
     assert response['status'] == '204'
-    assert response['etag'] == '"bag1/TestOne/4;text/plain"'
+    etag_hash = sha('GUEST:text/plain').hexdigest()
+    assert response['etag'] == '"bag1/TestOne/4;%s"' % etag_hash
 
 def test_get_tiddler_revision_list():
     http = httplib2.Http()
@@ -96,7 +101,8 @@ def test_get_tiddler_revision_3():
     response, content = http.request('http://our_test_domain:8001/bags/bag1/tiddlers/TestOne/revisions/3',
             method='GET')
     assert response['status'] == '200'
-    assert response['etag'] == '"bag1/TestOne/3;text/html"'
+    etag_hash = sha('GUEST:text/html').hexdigest()
+    assert response['etag'] == '"bag1/TestOne/3;%s"' % etag_hash
 
 def test_get_tiddler_revision_5_fail():
     http = httplib2.Http()
@@ -178,13 +184,14 @@ def test_etag_generation():
     tiddler = Tiddler('monkey', 'bar')
     etag = _tiddler_etag({'tiddlyweb.config': config}, tiddler)
 
-    assert etag == '"bar/monkey/0;"'
+    etag_hash = sha(':').hexdigest()
+    assert etag == '"bar/monkey/0;%s"' % etag_hash
 
     bag = Bag('bar')
     store.put(bag)
     store.put(tiddler)
     etag = _tiddler_etag({'tiddlyweb.config': config}, tiddler)
-    assert etag == '"bar/monkey/1;"'
+    assert etag == '"bar/monkey/1;%s"' % etag_hash
 
 
 def test_post_revision_etag_handling():
