@@ -4,6 +4,7 @@ Miscellaneous utility functions for TiddlyWeb.
 
 import codecs
 import os
+import sys
 
 try:
     from hashlib import sha1
@@ -36,6 +37,20 @@ def read_utf8_file(filename):
     return content
 
 
+def std_error_message(message):
+    """
+    Display a message on the stderr console.
+    """
+    try:
+        print >> sys.stderr, message.encode('utf-8', 'replace')
+    # there's a mismatch between our encoding and the output terminal
+    except UnicodeDecodeError:
+        try:
+            print >> sys.stderr, message
+        except UnicodeDecodeError:
+            print >> sys.stderr, 'cannot display message due to mismatching terminal character encoding'
+
+
 def write_utf8_file(filename, content):
     """
     Write a string to utf-8 encoded file.
