@@ -141,6 +141,26 @@ def _determine_tiddler(environ, bag_finder):
             raise HTTP404('%s not a revision of %s: %s' %
                     (revision, tiddler_name, exc))
 
+    # We have to deserialize the tiddler here so that
+    # PUTs to recipes are aware of values like tags when
+    # doing filter checks.
+    if environ['REQUEST_METHOD'] == 'PUT':
+        length, content_type = _length_and_type(environ)
+
+        if content_type != 'text/plain' and content_type != 'application/json':
+            tiddler.type = content_type
+
+        content = environ['wsgi.input'].read(int(length))
+
+        if not tiddler.type:
+            serialize_type = web.get_serialize_type(environ)[0]
+            serializer = Serializer(serialize_type, environ)
+            serializer.object = tiddler
+            serializer.from_string(content.decode('utf-8'))
+        else:
+            tiddler.text = content
+
+
 
     recipe_name = environ['wsgiorg.routing_args'][1].get('recipe_name', None)
     if recipe_name:
@@ -274,25 +294,11 @@ def _put_tiddler(environ, start_response, tiddler):
     not.
     """
     store = environ['tiddlyweb.store']
-    length, content_type = _length_and_type(environ)
-
-    if content_type != 'text/plain' and content_type != 'application/json':
-        tiddler.type = content_type
 
     try:
         bag = Bag(tiddler.bag)
         tiddler.revision = _check_and_validate_tiddler(environ, bag, tiddler)
 
-        content = environ['wsgi.input'].read(int(length))
-
-        if not tiddler.type:
-            serialize_type = web.get_serialize_type(environ)[0]
-            serializer = Serializer(serialize_type, environ)
-            serializer.object = tiddler
-            serializer.from_string(content.decode('utf-8'))
-        else:
-            tiddler.text = content
-
         user = environ['tiddlyweb.usersign']['name']
         if not user == 'GUEST':
             tiddler.modifier = user
@@ -421,8 +427,7 @@ def _send_tiddler(environ, start_response, tiddler):
     # we need the revision, which is sad
     last_modified, etag = _validate_tiddler_headers(environ, tiddler)
 
-    # If we have content that doesn't look like wikitext,
-    # we send it out straight up rather than using the serializer.
+    # make choices between binary or serialization
     content, mime_type = _get_tiddler_content(environ, tiddler)
 
     vary_header = ('Vary', 'Accept')
@@ -443,18 +448,24 @@ def _get_tiddler_content(environ, tiddler):
     Extract the content of the tiddler, either straight up if
     the content is not considered text, or serialized if it is
     """
-    if _not_wikitext(tiddler, environ['tiddlyweb.config']):
-        mime_type = tiddler.type
-        content = tiddler.text
-    else:
-        serialize_type, mime_type = web.get_serialize_type(environ)
-        serializer = Serializer(serialize_type, environ)
-        serializer.object = tiddler
+    serializers = environ['tiddlyweb.config']['serializers']
+    default_serialize_type = serializers['default'][0]
+    serialize_type, mime_type = web.get_serialize_type(environ)
 
-        try:
-            content = serializer.to_string()
-        except TiddlerFormatError, exc:
-            raise HTTP415(exc)
+    if _not_wikitext(tiddler, environ['tiddlyweb.config']):
+        if (serialize_type == default_serialize_type or
+                serialize_type == tiddler.type):
+            mime_type = tiddler.type
+            content = tiddler.text
+            return content, mime_type
+
+    serializer = Serializer(serialize_type, environ)
+    serializer.object = tiddler
+
+    try:
+        content = serializer.to_string()
+    except TiddlerFormatError, exc:
+        raise HTTP415(exc)
     return content, mime_type
 
 
